Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1176)

Unified Diff: chrome/utility/importer/ie_importer_win.cc

Issue 1082083004: Replace some GURL::SchemeIsSecure callers with SchemeUsesTLS. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@origin-is-secure-gurl
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/net/certificate_error_reporter.cc ('k') | chrome/utility/importer/nss_decryptor.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/utility/importer/ie_importer_win.cc
diff --git a/chrome/utility/importer/ie_importer_win.cc b/chrome/utility/importer/ie_importer_win.cc
index c9f9f623ece1c423e35e50f5975538b1b535bb0c..8da54a3da8b3f0f76ecf3df0c1472f1cd13dd565 100644
--- a/chrome/utility/importer/ie_importer_win.cc
+++ b/chrome/utility/importer/ie_importer_win.cc
@@ -632,9 +632,9 @@ void IEImporter::ImportPasswordsIE6() {
// This is not precise, because a scheme of https does not imply a valid
// certificate was presented; however we assign it this way so that if we
// import a password from IE whose scheme is https, we give it the benefit
- // of the doubt and DONT auto-fill it unless the form appears under
- // valid SSL conditions.
- form.ssl_valid = url.SchemeIsSecure();
+ // of the doubt and DON'T auto-fill it unless the form appears under
+ // valid TLS conditions.
+ form.ssl_valid = url.SchemeUsesTLS();
// Goes through the list to find out the username field
// of the web page.
« no previous file with comments | « chrome/browser/net/certificate_error_reporter.cc ('k') | chrome/utility/importer/nss_decryptor.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698